#使用turtle画一个篮球形状
import turtle
import math
turtle.showturtle
import math
turtle.pensize(3)
turtle.color("brown")
turtle.circle(50)
a=0
x=50
turtle.left(45)
turtle.circle(60,110)
turtle.penup()
turtle.goto(-50,50)
turtle.pendown()
turtle.left(180)
turtle.circle(90,66)
turtle.penup()
turtle.goto(-25,10)
turtle.pendown()
turtle.left(26)
turtle.circle(50,80)
turtle.penup()
turtle.goto(40,80)
turtle.right(-110)
turtle.pendown()
turtle.circle(90,35)
turtle.penup()
turtle.goto(0,-90)
turtle.done()