#coding=utf-8
from distutils.core import setup

setup(
    name='lanqiu',#模块的名字叫篮球的中文拼音
    version='1.0',#版本号，虽然我不确定还有第二版，嘿嘿！
    description='这是我第一个发布的模块，里面只是一个球的图案,勿喷哦',#内容描述
    author='Mr.wang',#全名就不告诉你。嘿嘿！
    author_email='174984428@qq.com',#还好我有个邮箱。
    py_modules=['basketball.lanqiu'],#好啦,就是篮球啦
)